.. :changelog:

History
-------

0.1.0 (2015-02-23)
---------------------

* First release on PyPI.


0.1.1 (2015-02-24)
---------------------

* update print_version()
* allow clingon to autoinstall in a more simpler way
* some minor fixes
³ some more unittests
